@@ -2,8 +2,8 @@
 Code generator functions for wxCalendarCtrl objects
 
 @copyright: 2002-2007 Alberto Griggio
-@copyright: 2014 Carsten Grohmann
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2014-2015 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import common
@@ -33,20 +33,15 @@ class PythonCalendarCtrlGenerator(wcodegen.PythonWidgetCodeWriter):
 
 
 class CppCalendarCtrlGenerator(wcodegen.CppWidgetCodeWriter):
-    extra_headers = ['<wx/calctrl.h>']
-    tmpl = '%(name)s = new %(klass)s(%(parent)s, %(id)s%(style)s);\n'
+    import_modules = ['<wx/calctrl.h>']
+    tmpl = '%(name)s = new %(klass)s(%(parent)s, %(id)s, wxDefaultDateTime' \
+           '%(style)s);\n'
 
     def _prepare_tmpl_content(self, obj):
         wcodegen.CppWidgetCodeWriter._prepare_tmpl_content(self, obj)
         self.has_setdefault = obj.properties.get('default', False)
         return
 
-    def get_events(self, obj):
-        """\
-        wxCalendarCtrl uses wxCalendarEvent for event handling
-        """
-        return self.codegen.get_events_with_type(obj, 'wxCalendarEvent')
-
 # end of class CppCalendarCtrlGenerator
 
 
