@@ -2,47 +2,63 @@
 Code generator functions for CustomWidget objects
 
 @copyright: 2002-2007 Alberto Griggio
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2015 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import logging
 
 import common
 import wcodegen
+from wcodegen.taghandler import BaseCodeWriterTagHandler
 
 
-class ArgumentsCodeHandler(object):
+class ArgumentsCodeHandler(BaseCodeWriterTagHandler):
+
     def __init__(self):
+        super(ArgumentsCodeHandler, self).__init__()
         self.arguments = []
-        self.curr_arg = []
-
-    def start_elem(self, name, attrs):
-        pass
 
     def end_elem(self, name, code_obj):
         if name == 'arguments':
             code_obj.properties['arguments'] = self.arguments
             return True
         elif name == 'argument':
-            tab_name = "".join(self.curr_arg)
+            tab_name = self.get_char_data()
             self.arguments.append(tab_name)
-            self.curr_arg = []
         return False
 
-    def char_data(self, data):
-        self.curr_arg.append(data)
-
 # end of class ArgumentsCodeHandler
 
 
-def _fix_arguments(arguments, parent, id, size):
-    # adding $width e $height:
+def format_ctor_arguments(arguments, parent, id, size):
+    """\
+    Format constructor arguments
+
+    @param arguments: Constructor arguments
+    @type arguments:  list
+
+    @param parent: Parent widget
+    @type parent: str | Unicode
+
+    @param id: Widget ID e.g. wxID_ANY
+    @type id: str
+
+    @param size: Widget size 'width, height'
+    @type size: str
+
+    @rtype: list
+    """
     vSize = size.split(',')
     for i in range(len(arguments)):
-        if arguments[i] == '$parent': arguments[i] = parent
-        elif arguments[i] == '$id': arguments[i] = id
-        elif arguments[i] == '$width': arguments[i] = vSize[0]
-        elif arguments[i] == '$height': arguments[i] = vSize[1]
+        if arguments[i] == '$parent':
+            arguments[i] = parent
+        elif arguments[i] == '$id':
+            arguments[i] = id
+        elif arguments[i] == '$width':
+            arguments[i] = vSize[0]
+        elif arguments[i] == '$height':
+            arguments[i] = vSize[1]
     return arguments
 
 
@@ -54,29 +70,24 @@ class PythonCustomWidgetGenerator(wcodegen.PythonWidgetCodeWriter):
             return self.get_code_preview(widget)
         prop = widget.properties
         id_name, id = self.codegen.generate_code_id(widget)
-        if not widget.parent.is_toplevel:
-            parent = 'self.%s' % widget.parent.name
-        else:
-            parent = 'self'
+        parent = self.format_widget_access(widget.parent)
         init = []
         if id_name: init.append(id_name)
-        arguments = _fix_arguments(
+        arguments = format_ctor_arguments(
             prop.get('arguments', []), parent, id,
             prop.get('size', '-1, -1').strip())
-        ctor = widget.klass
         cust_ctor = prop.get('custom_ctor', '').strip()
         if cust_ctor:
             ctor = cust_ctor
+        else:
+            ctor = widget.klass
         init.append('self.%s = %s(%s)\n' % (widget.name, ctor,
                                             ", ".join(arguments)))
         props_buf = self.codegen.generate_common_properties(widget)
         return init, props_buf, []
 
     def get_code_preview(self, widget):
-        if not widget.parent.is_toplevel:
-            parent = 'self.%s' % widget.parent.name
-        else:
-            parent = 'self'
+        parent = self.format_widget_access(widget.parent)
         init = []
         append = init.append
         append('self.%s = wx.Window(%s, -1)\n' % (widget.name, parent))
@@ -102,7 +113,7 @@ def self_%s_on_paint(event):
     dc.EndDrawing()    
 """ % ((widget.name,) * 3)
         for line in on_paint_code.splitlines():
-            append(line + '\n')        
+            append(line + '\n')
         append('wx.EVT_PAINT(self.%s, self_%s_on_paint)\n' %
                (widget.name, widget.name))
         return init, [], []
@@ -118,15 +129,18 @@ class CppCustomWidgetGenerator(wcodegen.CppWidgetCodeWriter):
             ids = [id_name]
         else:
             ids = []
-        if not widget.parent.is_toplevel: parent = '%s' % widget.parent.name
-        else: parent = 'this'
-        arguments = _fix_arguments(
+        if not widget.parent.is_toplevel:
+            parent = '%s' % widget.parent.name
+        else:
+            parent = 'this'
+        arguments = format_ctor_arguments(
             prop.get('arguments', []), parent, id,
             prop.get('size', '-1, -1').strip())
-        ctor = 'new ' + widget.klass
         cust_ctor = prop.get('custom_ctor', '').strip()
         if cust_ctor:
             ctor = cust_ctor
+        else:
+            ctor = 'new ' + widget.klass
         init = ['%s = %s(%s);\n' % (widget.name, ctor,
                                     ", ".join(arguments)) ]
         props_buf = self.codegen.generate_common_properties(widget)
@@ -139,8 +153,6 @@ def xrc_code_generator(obj):
     xrcgen = common.code_writers['XRC']
 
     class CustomXrcObject(xrcgen.DefaultXrcObject):
-        from xml.sax.saxutils import escape
-
         def write(self, outfile, ntabs):
             # first, fix the class:
             self.klass = obj.klass
@@ -151,7 +163,7 @@ def xrc_code_generator(obj):
             if 'arguments' in self.properties:
                 args = self.properties['arguments']
                 del self.properties['arguments']
-                for arg in args:           
+                for arg in args:
                     try:
                         name, val = [s.strip() for s in arg.split(':', 1)]
                     except Exception:
