@@ -2,12 +2,13 @@
 wxListBox objects
 
 @copyright: 2002-2007 Alberto Griggio
-@copyright: 2014 Carsten Grohmann
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2014-2015 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import wx
 import common
+import compat
 import misc
 from edit_windows import ManagedBase, EditStylesMixin
 from tree import Tree
@@ -20,8 +21,6 @@ class EditListBox(ManagedBase, EditStylesMixin):
     Class to handle wxListBox objects
     """
 
-    events = ['EVT_LISTBOX', 'EVT_LISTBOX_DCLICK']
-
     def __init__(self, name, parent, id, choices, sizer, pos, property_window,
                  show=True):
 
@@ -66,7 +65,7 @@ class EditListBox(ManagedBase, EditStylesMixin):
         ch.SetSize((ch.GetSize()[0]-20, 200))
         szr.Add(self.properties['choices'].panel, 1, wx.ALL|wx.EXPAND, 5)
         panel.SetAutoLayout(True)
-        panel.SetSizer(szr)
+        compat.SizerItem_SetSizer(panel, szr)
         szr.Fit(panel)
         w, h = panel.GetSize()
         from math import ceil
@@ -115,8 +114,7 @@ def builder(parent, sizer, pos, number=[1]):
         number[0] += 1
         name = 'list_box_%d' % number[0]
     list_box = EditListBox(name, parent, wx.NewId(),
-                           #[common.encode_from_xml('choice 1')], sizer, pos,
-                           [], sizer, pos,
+                           [u'choice 1', ], sizer, pos,
                            common.property_panel)
     node = Tree.Node(list_box)
 ##     sizer.set_item(pos, size=list_box.GetBestSize())
@@ -148,7 +146,7 @@ def xml_builder(attrs, parent, sizer, sizeritem, pos=None):
         common.app_tree.insert(node, sizer.node, pos - 1)
     return list_box
 
-    
+
 def initialize():
     """\
     initialization function for the module: returns a wxBitmapButton to be
@@ -157,4 +155,4 @@ def initialize():
     common.widgets['EditListBox'] = builder
     common.widgets_from_xml['EditListBox'] = xml_builder
 
-    return common.make_object_button('EditListBox', 'icons/list_box.xpm')
+    return common.make_object_button('EditListBox', 'list_box.xpm')
