@@ -2,8 +2,8 @@
 Lisp generator functions for wxToggleButton objects
 
 @copyright: 2002-2004 D. H. aka crazyinsomniac on sourceforge
-@copyright: 2014 Carsten Grohmann
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2014-2015 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import common
@@ -12,7 +12,7 @@ import wcodegen
 
 class LispToggleButtonGenerator(wcodegen.LispWidgetCodeWriter):
     tmpl = '(setf %(name)s (%(klass)s_Create %(parent)s %(id)s ' \
-           '%(label)s -1 -1 -1 -1 0))\n'
+           '%(label)s -1 -1 -1 -1 %(style)s))\n'
     has_setvalue = True
 
 # end of class LispToggleButtonGenerator
