@@ -3,8 +3,8 @@
 Entry point of wxGlade
 
 @copyright: 2002-2007 Alberto Griggio
-@copyright: 2013 Carsten Grohmann
-@license: MIT (see license.txt) - THIS PROGRAM COMES WITH NO WARRANTY
+@copyright: 2013-2015 Carsten Grohmann
+@license: MIT (see LICENSE.txt) - THIS PROGRAM COMES WITH NO WARRANTY
 """
 
 import atexit
@@ -16,6 +16,25 @@ import sys
 import gettext
 import optparse
 
+# Use a NullWriter with Unicode support (encoding attribute) to catch and
+# drop all output in PyInstaller environment (standalone Edition)
+#
+# Fix for PyInstaller bug #1324
+# https://github.com/pyinstaller/pyinstaller/issues/1324
+if hasattr(sys, 'frozen') and not hasattr(sys.stderr, 'encoding'):
+    class NullWriter(object):
+        softspace = 0
+        encoding = 'UTF-8'
+
+        def write(*args):
+            pass
+
+        def flush(*args):
+            pass
+
+    sys.stdout = NullWriter()
+    sys.stderr = NullWriter()
+
 t = gettext.translation(domain="wxglade", localedir="locale", fallback=True)
 t.install("wxglade")
 
@@ -47,10 +66,10 @@ Usage: wxglade <WXG File>             start the wxGlade GUI
         version=_("""\
 wxGlade version %s
 Copyright (C) 2007-2012 Alberto Griggio
-Copyright (C) 2011-2014 Carsten Grohmann
+Copyright (C) 2011-2015 Carsten Grohmann
 License MIT: The MIT License
              <http://www.opensource.org/licenses/mit-license.php>""") %
-        config.version
+        config.get_version()
         )
     parser.add_option(
         '-h',
@@ -182,22 +201,47 @@ def init_stage1():
     common.init_paths()
 
     # initialise own logging extensions
-    log.init(
-        filename=config.log_file,
-        encoding='utf-8',
-        level='INFO',
-        )
+    log.init(filename=config.log_file, encoding='utf-8', level='INFO')
     atexit.register(log.deinit)
 
-    # initialise localization
+    # print versions
+    logging.info(
+        _('Starting wxGlade version "%s" on Python %s'),
+        config.version,
+        config.py_version,
+        )
+
+    # print used paths
+    logging.info(_('Base directory:             %s'), config.wxglade_path)
+    logging.info(_('Documentation directory:    %s'), config.docs_path)
+    logging.info(_('Icons directory:            %s'), config.icons_path)
+    logging.info(_('Build-in widgets directory: %s'), config.widgets_path)
+    logging.info(_('Template directory:         %s'), config.templates_path)
+    logging.info(_('Credits file:               %s'), config.credits_file)
+    logging.info(_('License file:               %s'), config.license_file)
+    logging.info(_('Manual file:                %s'), config.manual_file)
+    logging.info(_('Tutorial file:              %s'), config.tutorial_file)
+    logging.info(_('Home directory:             %s'), config.home_path)
+    logging.info(_('Application data directory: %s'), config.appdata_path)
+    logging.info(_('Configuration file:         %s'), config.rc_file)
+    logging.info(_('History file:               %s'), config.history_file)
+    logging.info(_('Log file:                   %s'), config.log_file)
+
+    # adapt application search path
+    sys.path.insert(0, config.wxglade_path)
+    sys.path.insert(1, config.widgets_path)
+
+
+def init_localization():
+    """
+    Initialise localization
+    """
     encoding = None
     try:
         locale.setlocale(locale.LC_ALL, '')
     except locale.Error:
         # ignore problems by fallback to ascii
-        logging.warning(
-            _('Setting locale failed. Use "ascii" instead')
-            )
+        logging.warning(_('Setting locale failed. Use "ascii" instead'))
         encoding = 'ascii'
 
     # try to query character encoding used in the selected locale
@@ -206,9 +250,7 @@ def init_stage1():
             encoding = locale.nl_langinfo(locale.CODESET)
         except AttributeError, e:
             logging.warning(
-                _('locale.nl_langinfo(locale.CODESET) failed: %s'),
-                str(e)
-                )
+                _('locale.nl_langinfo(locale.CODESET) failed: %s'), str(e))
 
     # try getdefaultlocale, it used environment variables
     if not encoding:
@@ -220,9 +262,7 @@ def init_stage1():
     # On Mac OS X encoding may None or '' somehow
     if not encoding:
         encoding = config.default_encoding
-        logging.warning(
-            _('Empty encoding. Use "%s" instead'), encoding
-            )
+        logging.warning(_('Empty encoding. Use "%s" instead'), encoding)
 
     # check if a codec for the encoding exists
     try:
@@ -230,45 +270,17 @@ def init_stage1():
     except LookupError:
         logging.warning(
             _('No codec for encoding "%s" found. Use "ascii" instead'),
-            encoding
-            )
+            encoding)
         encoding = 'ascii'
 
-    # print versions
-    logging.info(
-        _("Starting wxGlade version %s on Python %s"),
-        config.version,
-        config.py_version,
-        )
-
-    # show current locale
+    # store determined encoding and show current locale
+    config.encoding = encoding.upper()
     loc_langcode, loc_encoding = locale.getlocale()
     logging.info(_('Current locale settings are:'))
     logging.info(_('  Language code: %s'), loc_langcode)
     logging.info(_('  Encoding: %s'), loc_encoding)
     logging.info(_('  Filesystem encoding: %s'), sys.getfilesystemencoding())
 
-    # store determined encoding
-    config.encoding = encoding.upper()
-
-    # print used paths
-    logging.info(_('Base directory:             %s'), config.wxglade_path)
-    logging.info(_('Documentation directory:    %s'), config.docs_path)
-    logging.info(_('Icons directory:            %s'), config.icons_path)
-    logging.info(_('Build-in widgets directory: %s'), config.widgets_path)
-    logging.info(_('Template directory:         %s'), config.templates_path)
-    logging.info(_('Credits file:               %s'), config.credits_file)
-    logging.info(_('License file:               %s'), config.license_file)
-    logging.info(_('Tutorial file:              %s'), config.tutorial_file)
-    logging.info(_('Home directory:             %s'), config.home_path)
-    logging.info(_('Application data directory: %s'), config.appdata_path)
-    logging.info(_('Configuration file:         %s'), config.rc_file)
-    logging.info(_('History file:               %s'), config.history_file)
-    logging.info(_('Log file:                   %s'), config.log_file)
-
-    # adapt application search path
-    sys.path = [config.wxglade_path, config.widgets_path] + sys.path
-
 
 def init_stage2(use_gui):
     """\
@@ -293,12 +305,17 @@ def init_stage2(use_gui):
             import wx
         except ImportError:
             logging.error(
-                _('Please install missing python module "wxPython".')
-                )
+                _('Please install missing python module "wxPython".'))
             sys.exit(1)
 
-        # store current version and platform
-        # ('not_set' is default)
+        try:
+            import faulthandler
+            faulthandler.enable()
+            logging.info(_('Python fault handler found and activated'))
+        except ImportError:
+            logging.debug(_('Python fault handler not found'))
+
+        # store current version and platform ('not_set' is default)
         config.platform = wx.Platform
         config.wx_version = wx.__version__
 
@@ -319,17 +336,9 @@ def run_main():
     # check command line parameters first
     options = parse_command_line()
 
-    # initialise wxGlade (first stage)
+    # initialise wxGlade (first stage and second stage)
     init_stage1()
-
-    # print versions
-    logging.info(
-        _("Starting wxGlade version %s on Python %s"),
-        config.version,
-        config.py_version,
-    )
-
-    # initialise wxGlade (second stage)
+    init_localization()
     init_stage2(options.start_gui)
 
     if options.start_gui:
